Updates the ggsci knowledge store
update_store.RdDownloads the latest version of the store from the brandthis GitHub repository and builds the search index locally.
Usage
update_store(pkg = c("paletteer", "ggsci"))Details
The download location can be configured with a few environment variables:
BRANDTHIS_STORE_URL: a custom URL to download the store from. The default is to download the latest store from thedurraniu/brandthisrepository in thestore-v1release.BRANDTHIS_STORE_RELEASE: the release tag to download the store from. Defaults tostore-v1.BRANDTHIS_STORE_REPOSITORY: the repository to download the store from. Defaults todurraniu/brandthis.